Skip to contents

[Experimental] Generate a rmarkdown PDF from a project object

Usage

rmarkdown_project(project, dir_other)

Arguments

project

project object from REDCapSync package

dir_other

Character. The directory where the dataset file will be saved. Default is the output folder within the database directory.

Details

You will need the tinytex and reticulate packages. Follow errors during your first use and afterwards it should work. Currently working on mac but troubleshooting windows errors with latex.